@@ -1,4 +1,4 @@
-import { merge } from "lodash";
+// import { merge } from "lodash";
 import { mapGetters, mapActions } from "vuex";
 
 export default {
@@ -16,7 +16,7 @@ export default {
     beforeDestroy(){
         window.removeEventListener('resize', this.handleResize);
     },
-    methods : merge(mapActions([ 'updateHeights' ]), {
+    methods : _.merge(mapActions([ 'updateHeights' ]), {
         handleResize (event) {
             if ( this.resize ) clearTimeout(this.resize);
             this.resize = setTimeout(() => {
