@@ -12,7 +12,23 @@ export const slide = {
         })
     }
 };
+export function cSlide(duration:number=300){
+    return {
+        slideEnter(el, done){
+            this.$$(el).slideDown({
+                duration,
+                done
+            })
+        },
+        slideLeave(el, done){
+            this.$$(el).slideUp({
+                duration,
+                done
+            })
+        }
 
+    }
+}
 export const fade = {
     fadeEnter(el, done){
         this.$$(el).fadeIn({
