@@ -2,18 +2,22 @@ import Vue from "vue";
 import components from '../components/document'
 import {merge} from 'lodash'
 
-let codex = window.codex;
+import { Collapse, Item as CollapseItem } from 'vue-bulma-collapse'
 
 Object.keys(components).forEach((key) => Vue.component(key, components[key]));
 
 var {mapGetters, mapActions, Store} = Vuex;
-
 export const store = new Store({});
-Vue.use(codex.CodexPlugin, {
-    store
-});
+Vue.use(Vue.codex.CodexPlugin, { store });
+
+
 export const App = Vue.extend({
     store,
+
+    components: {
+        Collapse,
+        CollapseItem
+    },
     mixins: [Vue.codex.mixins.layout, Vue.codex.mixins.resize],
     data(){
         return {
@@ -33,16 +37,17 @@ export const App = Vue.extend({
         }
     },
     mounted(){
-
         this.$$ready(() => {
             this.onResize();
-            this.$nextTick(() => codex.loader.stop());
+            this.$nextTick(() => Vue.codex.loader.stop());
         });
         this.$on('resize', this.onResize)
-        this.$eventHub.$on('sidebar:open-sub-menu', this.onResize)
+        this.$events.$on('sidebar:open-sub-menu', this.onResize)
     },
     methods : {
-        ...mapActions(['toggleSidebar', 'closeSidebar', 'openSidebar', 'hideSidebar', 'showSidebar']),
+        ...mapActions([
+            'toggleSidebar', 'closeSidebar', 'openSidebar', 'hideSidebar', 'showSidebar'
+        ]),
 
         showSidenav(name){
             this.sidenavs.opened = name;
@@ -102,4 +107,4 @@ export const App = Vue.extend({
 
 export default App;
 
-codex.App = App;
\ No newline at end of file
+Vue.codex.App = App;
\ No newline at end of file
