@@ -1,32 +1,42 @@
-import * as components from "components/phpdoc";
+// import * as components from "components/phpdoc";
 import * as directives from "./directives";
 import * as filters from "./filters";
-import * as api from './api'
-import {removeStartSlash} from './utils'
+import * as api from './utils/api'
+import * as mixins from './mixins'
+import * as utils from './utils'
+import PHPDoc from "./utils/PHPDoc";
+import { Tag } from "./utils/api";
 
-
-filters['removeStartSlash'] = removeStartSlash;
+filters[ 'removeStartSlash' ] = utils.removeStartSlash;
 
 
 let plugin: any = function (Vue, options: any = {}) {
     if ( plugin.installed ) return;
 
+    // let phpdoc = new PHPDoc(Vue.codex.store);
+
     Vue.codex.extend({
-        phpdoc: {
-            apiUrl: '/api/v1/',
-            api
-        }
+        phpdoc: _.merge({}, api, utils, {
+            mixins,
+        })
     })
 
-    console.log('phpdoc plugin', {components})
+
+    Object.defineProperties(Vue.prototype, {
+        $phpdoc: { get () { return Vue.codex.phpdoc } }
+    })
+
+    const components = require('components/phpdoc')
+
     Object.keys(components).forEach(key => Vue.component(key, components[ key ]));
     Object.keys(directives).forEach(key => Vue.directive(key, directives[ key ]));
     Object.keys(filters).forEach(key => Vue.filter(key, filters[ key ]));
 
     if ( Vue.codex.store ) {
-        var { module, types } = require('./store');
+        const { module, types } = require('./store');
         Vue.codex.store.registerModule('phpdoc', module);
         Vue.codex.phpdoc.types = types;
+
     }
 };
 
