@@ -1,10 +1,23 @@
+
+import 'assets/img/ss-codex-phpdoc.png'
+import 'assets/img/ss-codex-document.png'
+import 'assets/img/issue-addon-scan.png'
+import 'assets/img/issue-speed-improvements.png'
+import 'assets/img/issue-toolbar-styles.png'
+
+import 'assets/img/slides/slide-html.png'
+import 'assets/img/slides/slide-typewriter.jpg';
+
+import 'assets/img/features/fa-puzzle-piece-140x140-37474f.png'
+import 'assets/img/features/transgender-alt-140x140-263238.png'
+import 'assets/img/features/responsive.png'
+
 import Vue from "vue";
 import components from '../components/welcome';
 
 let codex =  window.codex;
 
 Object.keys(components).forEach(key => Vue.component(key, components[key]));
-
 const wow = new WOW({
     mobile: false,
 });
@@ -18,7 +31,9 @@ Vue.codex.extend({ wow, store })
 
 const App = Vue.extend({
     store,
+
     mixins : [Vue.codex.mixins.layout, Vue.codex.mixins.resize],
+//        template: welcome(),
     data(){
         return {
             carouselHeight: 9999
@@ -47,3 +62,4 @@ const App = Vue.extend({
 });
 
 codex.App = App;
+
